@@ -9,11 +9,13 @@
 
 
 #include "cuhre_decl.h"
-/* globals */
+
+typedef struct {
  count ndim_, ncomp_, nregions_;
  number neval_;
  real *lower_, *upper_,  prdbounds_;
- Integrand integrand_;
+} Glob;
+
 enum { nrules = 5 };
 
 #define CUHRETYPEDEFSET \
@@ -21,7 +23,7 @@ enum { nrules = 5 };
     count n; \
     real weight[5], scale[5], norm[5]; \
     real gen[MAXNDIM]; \
-  } Set
+  } Set;
 
 #ifdef DEBUG
 #include "common_debug.h"
